@@ -1,6 +1,6 @@
 #!/bin/sh
 #
-# Script to back uninstall Shoreline Firewall 6
+# Script to back uninstall Shoreline Firewall
 #
 #     (c) 2000-2016 - Tom Eastep (teastep@shorewall.net)
 #
@@ -26,14 +26,18 @@
 #       You may only use this script to uninstall the version
 #       shown below. Simply run this script to remove Shorewall Firewall
 
-VERSION=5.0.15
-PRODUCT=shorewall6
-Product=Shorewall6
+VERSION=5.1.2.3
+PRODUCT=shorewall
+Product=Shorewall
 
 usage() # $1 = exit status
 {
     ME=$(basename $0)
-    echo "usage: $ME [ <shorewallrc file> ]"
+    echo "usage: $ME [ <option> ] [ <shorewallrc file> ]"
+    echo "where <option> is one of"
+    echo "  -h"
+    echo "  -v"
+    echo "  -n"
     exit $1
 }
 
@@ -119,15 +123,11 @@ while [ $finished -eq 0 ]; do
     esac
 done
 
-#
-# Read the RC file
-#
 if [ $# -eq 0 ]; then
     if [ -f ./shorewallrc ]; then
 	. ./shorewallrc
     elif [ -f ~/.shorewallrc ]; then
 	. ~/.shorewallrc || exit 1
-	file=./.shorewallrc
     elif [ -f /usr/share/shorewall/shorewallrc ]; then
 	. /usr/share/shorewall/shorewallrc
     else
@@ -148,30 +148,33 @@ else
     usage 1
 fi
 
-if [ -f ${SHAREDIR}/shorewall6/version ]; then
-    INSTALLED_VERSION="$(cat ${SHAREDIR}/shorewall6/version)"
+if [ -f ${SHAREDIR}/shorewall/version ]; then
+    INSTALLED_VERSION="$(cat ${SHAREDIR}/shorewall/version)"
     if [ "$INSTALLED_VERSION" != "$VERSION" ]; then
-	echo "WARNING: Shorewall6 Version $INSTALLED_VERSION is installed"
+	echo "WARNING: Shorewall Version $INSTALLED_VERSION is installed"
 	echo "         and this is the $VERSION uninstaller."
 	VERSION="$INSTALLED_VERSION"
     fi
 else
-    echo "WARNING: Shorewall6 Version $VERSION is not installed"
+    echo "WARNING: Shorewall Version $VERSION is not installed"
     VERSION=""
 fi
 
-echo "Uninstalling shorewall6 $VERSION"
+
+echo "Uninstalling shorewall $VERSION"
 
 [ -n "$SANDBOX" ] && configure=0
 
 if [ $configure -eq 1 ]; then
-    if qt ip6tables -L shorewall6 -n && [ ! -f ${SBINDIR}/shorewall6-lite ]; then
-	${SBINDIR}/shorewall6 clear
+    if qt iptables -L shorewall -n && [ ! -f ${SBINDIR}/shorewall-lite ]; then
+	shorewall clear
     fi
 fi
 
-if [ -L ${SHAREDIR}/shorewall6/init ]; then
-    FIREWALL=$(readlink -m -q ${SHAREDIR}/shorewall6/init)
+rm -f ${SBINDIR}/shorewall
+
+if [ -L ${SHAREDIR}/shorewall/init ]; then
+    FIREWALL=$(readlink -m -q ${SHAREDIR}/shorewall/init)
 elif [ -n "$INITFILE" ]; then
     FIREWALL=${INITDIR}/${INITFILE}
 fi
@@ -179,7 +182,7 @@ fi
 if [ -f "$FIREWALL" ]; then
     if [ $configure -eq 1 ]; then
 	if mywhich updaterc.d ; then
-	    updaterc.d shorewall6 remove
+	    updaterc.d ${PRODUCT} remove
 	elif mywhich insserv ; then
             insserv -r $FIREWALL
 	elif mywhich chkconfig ; then
@@ -190,38 +193,51 @@ if [ -f "$FIREWALL" ]; then
     remove_file $FIREWALL
 fi
 
-[ -n "$SERVICEDIR" ] || SERVICEDIR=${SYSTEMD}
-
+if [ -z "${SERVICEDIR}" ]; then
+    SERVICEDIR="$SYSTEMD"
+fi
 if [ -n "$SERVICEDIR" ]; then
     [ $configure -eq 1 ] && systemctl disable ${PRODUCT}
-    rm -f $SERVICEDIR/shorewall6.service
+    rm -f $SERVICEDIR/shorewall.service
 fi
 
-rm -rf ${SHAREDIR}/shorewall6/version
-rm -rf ${CONFDIR}/shorewall6
+rm -rf ${SHAREDIR}/shorewall/version
+rm -rf ${CONFDIR}/shorewall
 
 if [ -n "$SYSCONFDIR" ]; then
     [ -n "$SYSCONFFILE" ] && rm -f ${SYSCONFDIR}/${PRODUCT}
 fi
 
-rm -f ${SBINDIR}/shorewall6
-rm -rf ${CONFDIR}/shorewall6
-rm -rf ${VARDIR}
-rm -rf ${LIBEXECDIR}/shorewall6
-rm -rf ${SHAREDIR}/shorewall6
+rm -rf ${VARDIR}/shorewall
+rm -rf ${PERLLIBDIR}/Shorewall/*
+[ ${LIBEXECDIR} = ${SHAREDIR} ] || rm -rf ${LIBEXECDIR}/shorewall
+rm -rf ${SHAREDIR}/shorewall/configfiles/
+rm -rf ${SHAREDIR}/shorewall/Samples/
+rm -rf ${SHAREDIR}/shorewall/Shorewall/
+rm -f  ${SHAREDIR}/shorewall/lib.cli-std
+rm -f  ${SHAREDIR}/shorewall/lib.runtime
+rm -f  ${SHAREDIR}/shorewall/compiler.pl
+rm -f  ${SHAREDIR}/shorewall/prog.*
+rm -f  ${SHAREDIR}/shorewall/module*
+rm -f  ${SHAREDIR}/shorewall/helpers
+rm -f  ${SHAREDIR}/shorewall/action*
+rm -f  ${SHAREDIR}/shorewall/macro.*
+rm -f  ${SHAREDIR}/shorewall/init
 
-for f in ${MANDIR}/man5/shorewall6* ${SHAREDIR}/man/man8/shorewall6*; do
+for f in ${MANDIR}/man5/shorewall* ${MANDIR}/man8/shorewall*; do
     case $f in
-	shorewall6-lite*)
+	shorewall6*|shorewall-lite*)
 	    ;;
 	*)
 	    rm -f $f
+	    ;;
     esac
 done
 
-rm -f  ${CONFDIR}/logrotate.d/shorewall6
-[ -n "$SYSTEMD" ] && rm -f ${SYSTEMD}/shorewall6.service
+rm -f  ${CONFDIR}/logrotate.d/shorewall
 
-echo "Shorewall6 Uninstalled"
+[ -n "$SYSTEMD" ] && rm -f  ${SYSTEMD}/shorewall.service
+
+echo "Shorewall Uninstalled"
 
 
